@@ -3,11 +3,16 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.001004'; # VERSION
+our $VERSION = '2.002000'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
-with 'Dist::Zilla::Role::TextTemplate';
+with (
+	'Dist::Zilla::Role::TextTemplate',
+	'Dist::Zilla::Role::FileFinderUser' => {
+		default_finders => [ ':InstallModules' ],
+	},
+);
 
 sub mvp_multivalue_args { return qw( stopwords ) }
 
@@ -61,6 +66,18 @@ around add_file => sub {
 		$self->log_debug( 'no copyright_holder found' );
 	}
 
+	foreach my $file ( @{ $self->found_files } ) {
+		# many of my stopwords are part of a filename
+		$self->log_debug( 'splitting filenames for more words' );
+
+		foreach ( split( '/', $file->name ) ) {
+			my ( $word ) = $_ =~ /(\w+)/xms;
+			$self->log_debug( 'word: ' . $word);
+
+			$self->push_stopwords( $word );
+		}
+	}
+
 	unless ( $self->no_stopwords ) {
 		$add_stopwords = 'add_stopwords(<DATA>);';
 		$stopwords = join "\n", '__DATA__', $self->uniq_stopwords;
@@ -97,7 +114,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.001004
+version 2.002000
 
 =head1 SYNOPSIS
 
@@ -198,6 +215,7 @@ This is free software, licensed under:
 __DATA__
 ___[ xt/author/pod-spell.t ]___
 #!perl
+
 # This test is generated by Dist::Zilla::Plugin::Test::PodSpelling
 
 use Test::More;
